#
# spec file for package python-intervaltree
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-intervaltree
Version:        3.1.0
Release:        2.1
Summary:        Editable interval tree data structure for Python
License:        Apache-2.0
URL:            https://github.com/chaimleib/intervaltree
Source:         https://files.pythonhosted.org/packages/source/i/intervaltree/intervaltree-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sortedcontainers}
# /SECTION
Requires:       python-sortedcontainers
BuildArch:      noarch

%python_subpackages

%description
A mutable, self-balancing interval tree for Python 2 and 3. Queries may
be by point, by range overlap, or by range envelopment.

This library was designed to allow tagging text and time intervals,
where the intervals include the lower bound but not the upper bound.

%prep
%setup -q -n intervaltree-%{version}
# Fix non-executable script
sed -i -e '/^#!\//, 1d' intervaltree/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/intervaltree
%{python_sitelib}/intervaltree-%{version}.dist-info

%changelog
* Fri May  9 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Sun Jul 24 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.0:
  - Dropped support for Python 3.4, added Python 3.8
  - Add `__slots__` optimization in Node class, should give performance improvement
  - Fixed:
  - Restore universal wheels
  - Bytes/str type incompatibility in setup.py
  - New version of distutils rejects version suffixes of `.postNN`, use `aNN` instead
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to Version 3.0.2
  + Fixed:
  * On some systems, setup.py opened README.md with a non-unicode encoding. My fault for leaving the encoding flapping in the breeze. It's been fixed.
- Update to Version 3.0.1
  + Added:
  * Travis testing for 3.7 and 3.8-dev. These needed OpenSSL, sudo and Xenial. 3.8-dev is allowed to fail.
  + Fixed:
  * PyPI wasn't rendering markdown because I didn't tell it what format to use.
  * Python 2 wasn't installing via pip because of a new utils package. It has been zapped.
  + Maintainers:
  * TestPyPI version strings use .postN as the suffix instead of bN, and N counts from the latest tagged commit, which should be the last release
  * Install from TestPyPI works via make install-testpypi
- Update to Version 3.0.0
  + Breaking:
  * search(begin, end, strict) has been replaced with at(point), overlap(begin, end), and envelop(begin, end)
  * extend(items) has been deleted, use update(items) instead
  * Methods that take a strict=True/False argument now consistently default to strict=True
  * Dropped support for Python 2.6, 3.2, and 3.3
  * Add support for Python 3.5, 3.6, and 3.7
  * Faster Interval overlap checking (@tuxzz, #56)
  + Updated README:
  * new restructuring methods from 2.1.0
  * example of from_tuples() added
  * more info about chop(), split_overlaps(), merge_overlaps() and merge_equals().
  + Fixes:
  * Node.from_tuples() will now raise an error if given an empty iterable. This should never happen, and it should error if it does.
  * Interval.distance_to() gave an incorrect distance when passed the Interval's upper boundary
  * Node.pop_greatest_child() sometimes forgot to rotate() when creating new child nodes. (@escalonn, #41, #42)
  * IntervalTree.begin() and end() are O(1), not O(n). (@ProgVal, #40)
  * intersection_update() and symmetric_difference() and symmetric_difference_update() didn't actually work. Now they do.
  * collections.abc deprecation warning no longer happens
  + Maintainers:
  * PyPi accepts Markdown! Woohoo!
  * reorganize tests
  * more tests added to improve code coverage (We're at 96%%! Yay!)
  * test for issue #4 had a broken import reference
* Sat Nov  3 2018 Todd R <toddrme2178@gmail.com>
- Initial version
